@@ -3,10 +3,13 @@ import os
 
 from zygoat.components import Component
 from zygoat.constants import Phases, Projects
-from zygoat.utils.backend import install_dependencies, dev_file_name, prod_file_name
+from zygoat.utils.backend import install_dependencies
 
 log = logging.getLogger()
 
+project_file_name = "pyproject.toml"
+lock_file_name = "poetry.lock"
+
 
 class Dependencies(Component):
     def create(self):
@@ -20,13 +23,13 @@ class Dependencies(Component):
             "django-anymail",
             "zygoat-django",
             "gunicorn",
-            "uvicorn",
+            "uvicorn[standard]",
         ]
 
         dev_dependencies = ["pytz", "factory-boy", "flake8-black", "bandit"]
 
         log.info("Installing production dependencies")
-        install_dependencies(*dependencies, extras={"uvicorn": ["standard"]})
+        install_dependencies(*dependencies)
 
         log.info("Installing dev dependencies")
         install_dependencies(*dev_dependencies, dev=True)
@@ -36,7 +39,9 @@ class Dependencies(Component):
 
     @property
     def installed(self):
-        paths = [os.path.join(Projects.BACKEND, p) for p in [prod_file_name, dev_file_name]]
+        paths = [
+            os.path.join(Projects.BACKEND, p) for p in [project_file_name, lock_file_name]
+        ]
 
         for path in paths:
             if not os.path.exists(path):
