@@ -1,20 +1,17 @@
 import logging
-from shutil import which
 
 from zygoat.components import Component
-from zygoat.constants import Phases, Projects
-from zygoat.utils.files import use_dir
-from zygoat.utils.shell import run
+from zygoat.constants import Phases, Projects, Images
+from zygoat.utils.shell import multi_docker_run
 
 log = logging.getLogger()
 
 
 class Reformat(Component):
     def create(self):
-        with use_dir(Projects.BACKEND):
-            black = which("black")
-            if black is not None:
-                run([black, "."])
+        multi_docker_run(
+            [["pip", "install", "black"], ["black", "."]], Images.PYTHON, Projects.BACKEND
+        )
 
     def update(self):
         self.call_phase(Phases.CREATE, force_create=True)
