@@ -3,8 +3,8 @@ import os
 import shutil
 
 from zygoat.components import Component
-from zygoat.constants import Projects, Phases
-from zygoat.utils.shell import run
+from zygoat.constants import Projects, Phases, Images
+from zygoat.utils.shell import docker_run
 from zygoat.utils.files import use_dir
 
 from .dockerfile import dockerfile
@@ -21,11 +21,8 @@ log = logging.getLogger()
 
 class Frontend(Component):
     def create(self):
-        log.info("Installing/upgrading yarn through npm")
-        run(["npm", "install", "-g", "--upgrade", "yarn"])
-
         log.info("Running create-next-app")
-        run(["yarn", "create", "next-app", Projects.FRONTEND])
+        docker_run(["yarn", "create", "next-app", Projects.FRONTEND], Images.NODE, ".")
 
         log.info("Emptying a poorly formatted index.js file")
         open(os.path.join(Projects.FRONTEND, "pages", "index.js"), "w").close()
@@ -52,7 +49,7 @@ class Reformat(Component):
     def create(self):
         log.info("Formatting package.json with prettier")
         with use_dir(Projects.FRONTEND):
-            run(["yarn", "prettier", "-w", "package.json"])
+            docker_run(["yarn", "prettier", "-w", "package.json"], Images.NODE, ".")
 
     def update(self):
         self.call_phase(Phases.CREATE, force_create=True)
