@@ -1,6 +1,5 @@
 from zygoat.components import Component
 
-from .codebuild import codebuild
 from .gitignore import gitignore
 from .configuration import configuration
 
@@ -9,4 +8,4 @@ class Cypress(Component):
     pass
 
 
-cypress = Cypress(sub_components=[configuration, gitignore, codebuild])
+cypress = Cypress(sub_components=[configuration, gitignore])
