@@ -18,17 +18,8 @@ class ZygoatNextConfigFile(FileComponent):
     overwrite = True
 
 
-class BabelConfigFile(FileComponent):
-    resource_pkg = resources
-    base_path = Projects.FRONTEND
-    filename = ".babelrc"
-    overwrite = False
-
-
 class NextConfig(Component):
     pass
 
 
-next_config = NextConfig(
-    sub_components=[NextConfigFile(), ZygoatNextConfigFile(), BabelConfigFile()]
-)
+next_config = NextConfig(sub_components=[NextConfigFile(), ZygoatNextConfigFile()])
